@@ -1,4 +1,4 @@
-;; -*- coding: iso-2022-8bit-ss2; -*-
+;; -*- coding: ctext; -*-
 
 (defvar rail-semi-codename-alist
   '(("Kaga-Ichinomiya"    . "$(B2C2l0l$N5\(B")
@@ -7,13 +7,13 @@
     ("Hinomiko"           . "$(BF|8f;R(B")
     ("Oyanagi"            . "$(B>.Lx(B")
     ("Inokuchi"           . "$(B0f8}(B")
-    ("D-Dhji-A"             . "$(BF;K!;{(B")
+    ("D-Dhji"-A             . "$(BF;K!;{(B")
     ("Sodani"             . "$(BA>C+(B")
     ("Shijima"            . "$(B;M==K|(B")
     ("Otomaru"            . "$(B254](B")
-    ("Nukaj-Dtaku-mae-A"     . "$(B3[=;BpA0(B")
+    ("Nukaj-Dtaku-mae"-A     . "$(B3[=;BpA0(B")
     ("Magae"              . "$(BGOBX(B")
-    ("Nonoichi-K-Ddaimae-A"  . "$(BLn!9;T9)BgA0(B")
+    ("Nonoichi-K-Ddaimae"-A  . "$(BLn!9;T9)BgA0(B")
     ("Nonoichi"           . "$(BLn!9;T(B")
     ("Oshino"             . "$(B2!Ln(B")
     ("Shin-Nishikanazawa" . "$(B?7@>6bBt(B")
@@ -24,17 +24,17 @@
     ("Arimagawa"          . "$(BM-4V@n(B")
     ("Nadachi"            . "$(BL>N)(B")
     ("Tsutsuishi"         . "$(BE{@P(B")
-    ("N-D-A"                 . "$(BG=@8(B")
+    ("N-D"-A                 . "$(BG=@8(B")
     ("Uramoto"            . "$(B1:K\(B")
     ("Kajiyashiki"        . "$(B3a20I_(B")
     ("Itoigawa"           . "$(B;e5{@n(B")
-    ("-Dmi-A"                . "$(B@D3$(B")
+    ("-Dmi"-A                . "$(B@D3$(B")
     ("Oyashirazu"         . "$(B?FITCN(B")
     ("Ichiburi"           . "$(B;T?6(B")
-    ("Ecch-D-Miyazaki-A"     . "$(B1[Cf5\:j(B")
+    ("Ecch-D-Miyazaki"-A     . "$(B1[Cf5\:j(B")
     ("Tomari"             . "$(BGq(B")
-    ("Ny-Dzen-A"             . "$(BF~A1(B")
-    ("Nishi-Ny-Dzen-A"       . "$(B@>F~A1(B")
+    ("Ny-Dzen"-A             . "$(BF~A1(B")
+    ("Nishi-Ny-Dzen"-A       . "$(B@>F~A1(B")
     ("Ikuji"              . "$(B@8CO(B")
     ("Kurobe"             . "$(B9uIt(B")
     ("Uozu"               . "$(B5{DE(B")
@@ -45,8 +45,7 @@
     ("Toyama"             . "$(BIY;3(B")
     ("Kureha"             . "$(B8b1)(B")
     ("Kosugi"             . "$(B>.?y(B")
-    ("Ecch-D-Daimon-A"       . "$(B1[CfBgLg(B")
-    ("Takaoka"            . "$(B9b2,(B")
+    ("Ecch-D-Daimon"-A       . "$(B1[CfBgLg(B")
     ("Nishi-Takaoka"      . "$(B@>9b2,(B")
     ("Fukuoka"            . "$(BJ!2,(B")
     ("Isurugi"            . "$(B@PF0(B")
@@ -57,17 +56,17 @@
     ("Kanazawa"           . "$(B6bBt(B")
     ("Nishi-Kanazawa"     . "$(B@>6bBt(B")
     ("[JR] Nonoichi"      . "[JR] $(BLn!9;T(B")
-    ("Matt-D-A"              . "$(B>>G$(B")
+    ("Matt-D"-A              . "$(B>>G$(B")
     ("Kaga-Kasama"        . "$(B2C2l3^4V(B")
     ("Mikawa"             . "$(BH~@n(B")
     ("Komaiko"            . "$(B>.Iq;R(B")
     ("Terai"              . "$(B;{0f(B")
-    ("Meih-D-A"              . "$(BL@Jv(B")
+    ("Meih-D"-A              . "$(BL@Jv(B")
     ("Komatsu"            . "$(B>.>>(B")
     ("Awazu"              . "$(B0@DE(B")
     ("Tsuruga"            . "$(BFX2l(B")
     ("Shin-Hikida"        . "$(B?7I%ED(B")
-    ("-Dmi-Shiotsu-A"        . "$(B6a9>1vDE(B")
+    ("-Dmi-Shiotsu"-A        . "$(B6a9>1vDE(B")
     ("Yogo"               . "$(BM>8b(B")
     ("Kinomoto"           . "$(BLZ%NK\(B")
     ("Takatsuki"          . "$(B9b7n(B")
@@ -76,20 +75,20 @@
     ("Nagahama"           . "$(BD9IM(B")
     ("Tamura"             . "$(BEDB<(B")
     ("Sakata"             . "$(B:dED(B")
-    ("T-Dky-A"              . "$(BEl5~(B")
+    ("T-Dky"-A              . "$(BEl5~(B")
     ("Shinbashi"          . "$(B?766(B")
     ("Shinagawa"          . "$(BIJ@n(B")
     ("Kawasaki"           . "$(B@n:j(B")
     ("Yokohama"           . "$(B2#IM(B")
     ("Totsuka"            . "$(B8MDM(B")
-    ("-Dfuna-A"              . "$(BBgA%(B")
+    ("-Dfuna"-A              . "$(BBgA%(B")
     ("Fujisawa"           . "$(BF#Bt(B")
-    ("Tsujid-D-A"            . "$(@DT$(BF2(B")
+    ("Tsujid-D"-A            . "$(BDTF2(B")
     ("Chigasaki"          . "$(B3}%v:j(B")
     ("Hiratsuka"          . "$(BJ?DM(B")
-    ("-Diso-A"               . "$(BBg0k(B")
+    ("-Diso"-A               . "$(BBg0k(B")
     ("Ninomiya"           . "$(BFs5\(B")
-    ("K-Dzu-A"               . "$(B9qI\DE(B")
+    ("K-Dzu"-A               . "$(B9qI\DE(B")
     ("Kamonomiya"         . "$(B3{5\(B")
     ("Odawara"            . "$(B>.ED86(B")
     ("Hayakawa"           . "$(BAa@n(B")
@@ -118,15 +117,15 @@
     ("Yaizu"              . "$(B>FDE(B")
     ("Nishi-Yaizu"        . "$(B@>>FDE(B")
     ("Fijieda"            . "$(BF#;^(B")
-    ("Rokug-D-A"             . "$(BO;9g(B")
+    ("Rokug-D"-A             . "$(BO;9g(B")
     ("Shimada"            . "$(BEgED(B")
     ("Kanaya"             . "$(B6bC+(B")
     ("Kikugawa"           . "$(B5F@n(B")
     ("Kakegawa"           . "$(B3]@n(B")
     ("Fukuroi"            . "$(BB^0f(B")
     ("Iwata"              . "$(BHXED(B")
-    ("Toyodach-D-A"          . "$(BK-EDD.(B")
-    ("Tenry-Dgawa-A"         . "$(BE7N5@n(B")
+    ("Toyodach-D"-A          . "$(BK-EDD.(B")
+    ("Tenry-Dgawa"-A         . "$(BE7N5@n(B")
     ("Hamamatsu"          . "$(BIM>>(B")
     ("Takatsuka"          . "$(B9bDM(B")
     ("Maisaka"            . "$(BIq:e(B")
@@ -137,27 +136,37 @@
     ("Futagawa"           . "$(BFs2O(B")
     ("Toyohashi"          . "$(BK-66(B")
     ("Kanayama"           . "$(B6b;3(B")
-    ("Ot-Dbashi-A"           . "$(BHxF,66(B")
+    ("Ot-Dbashi"-A           . "$(BHxF,66(B")
     ("Nagoya"             . "$(BL>8E20(B")
     ("Gifu"               . "$(B4tIl(B")
     ("Samegai"            . "$(B@C%v0f(B")
     ("Maibara"            . "$(BJF86(B")
     ("Kusatsu"            . "$(BApDE(B")
     ("Yamashina"          . "$(B;32J(B")
-    ("Ky-Dto-A"              . "$(B5~ET(B")
-    ("-Dsaka-A"              . "$(BBg:e(B")
-    ("K-Dbe-A"               . "$(B?@8M(B")
+    ("Ky-Dto"-A              . "$(B5~ET(B")
+    ("-Dsaka"-A              . "$(BBg:e(B")
+    ("K-Dbe"-A               . "$(B?@8M(B")
     ("Himi"               . "$(BI98+(B")
     ("Shimao"             . "$(BEgHx(B")
     ("Amaharashi"         . "$(B1+@2(B")
-    ("Ecch-D-Kokubu-A"       . "$(B1[Cf9qJ,(B")
+    ("Ecch-D-Kokubu"-A       . "$(B1[Cf9qJ,(B")
     ("Fushiki"            . "$(BIzLZ(B")
-    ("N-Dmachi-A"            . "$(BG=D.(B")
-    ("Ecch-D-Nakagawa-A"     . "$(B1[CfCf@n(B")
+    ("N-Dmachi"-A            . "$(BG=D.(B")
+    ("Ecch-D-Nakagawa"-A     . "$(B1[CfCf@n(B")
     ("Takaoka"            . "$(B9b2,(B")
     ("Saigata"            . "$(B:T3c(B")
     ("Kubiki"             . "$(B$/$S$-(B")
-    ("-Dike-Ikoinomori-A"    . "$(BBgCS$$$3$$$N?9(B")
-    ("Nishi--Dtsu-A"         . "$(B@>BgDE(B")))
+    ("-Dike-Ikoinomori"-A    . "$(BBgCS$$$3$$$N?9(B")
+    ("Uragawara"          . "$(B$&$i$,$o$i(B")
+    ("Mushigawa-Dsugi"-A     . "$(BCn@nBg?y(B")
+    ("Hokuhoku--Dshima"-A    . "$(B$[$/$[$/BgEg(B")
+    ("Matsudai"           . "$(B$^$D$@$$(B")
+    ("T-Dkamachi"-A          . "$(B==F|D.(B")
+    ("Shinza"             . "$(B$7$s$6(B")
+    ("Misashima"          . "$(BH~:4Eg(B")
+    ("Uonumaky-Dry"-A       . "$(B5{>B5VNM(B")
+    ("Uonuma-ky-Dry"-A      . "$(B5{>B5VNM(B")
+    ("Muikamachi"         . "$(BO;F|D.(B")
+    ("Nishi--Dtsu"-A         . "$(B@>BgDE(B")))
 
 (provide 'rail-table-semi)
